import knexCleaner from 'knex-cleaner';
import knex from '../lib/knex';
import {getOrCreateUser} from '../lib/get_user';

jest.setTimeout(30000);

beforeEach(async () => {
  await knexCleaner.clean(knex, {ignoreTables: ['knex_migrations']});
  await knex.migrate.latest();
  await knex.seed.run();
});

afterEach(async () => {
  await knex.destroy();
  await knex.initialize();
});

test('get existing user', async () => {
  const user = await getOrCreateUser({
    sub: 'oauth2|CILogon|http://cilogon.org/serverA/users/51521271',
    name: 'Rheya Vithalani',
    email: 'rrv7869@nyu.edu',
  });
  expect(user).toEqual({
    user_id: 4,
    name: 'Rheya Vithalani',
    email_address: 'rrv7869@nyu.edu',
    auth0_sub: 'oauth2|CILogon|http://cilogon.org/serverA/users/51521271',
  });
});

test('create new user', async () => {
  const subId = Math.random() % 10000;
  const sub = 'oauth2|CILogon|http://cilogon.org/serverA/users/' + subId;
  const user = await getOrCreateUser({
    sub,
    name: 'Test User',
    email: 'unk@nyu.edu',
  });
  expect(user).toEqual({
    user_id: 5,
    name: 'Test User',
    email_address: 'unk@nyu.edu',
    auth0_sub: sub,
  });
});
