import Link from 'next/link';
import {Space, TeamOrOwners, User} from '../database/models';
import {LinkSpace} from '../components/links';

export function Dashboard({
  user,
  ownedSpaces,
  spaces,
}: {
  user: User;
  ownedSpaces: Space[];
  spaces: Array<{space: Space; team: TeamOrOwners}>;
}) {
  return (
    <>
      <h1>Welcome to the HSRN dashboard, {user.name}</h1>
      <p>Owned spaces:</p>
      <ul>
        {ownedSpaces.map(s => (
          <li key={s.space_id}>
            <LinkSpace name={s.fullname}>
              {s.fullname}({s.space_id})
            </LinkSpace>
          </li>
        ))}
      </ul>
      <p>All spaces:</p>
      <ul>
        {spaces.map(s => {
          const space = `${s.space.fullname}(${s.space.space_id})`;
          let team = 'owners';
          if (s.team !== 'owners') {
            team = `${s.team.name}(${s.team.team_id})`;
          }
          return (
            <li key={s.space.space_id}>
              <LinkSpace name={s.space.fullname}>{space}</LinkSpace>
              &gt;{team}
            </li>
          );
        })}
      </ul>
      <p>
        <Link href="/kubeconfig">Get your kubernetes config file</Link>
      </p>
      <p>
        <Link href="/api/auth/logout">Logout</Link>
      </p>
    </>
  );
}
