import Link from 'next/link';
import {Resource} from '../database/models';

export function getSpaceUrl(spaceName: string): string {
  return '/s/' + spaceName;
}

export function LinkSpace({
  name,
  children,
}: {
  name: string;
  children: React.ReactNode;
}) {
  return (
    <Link href={getSpaceUrl(name)}>
      <a>{children}</a>
    </Link>
  );
}

export function LinkSpaceAudit({
  name,
  children,
}: {
  name: string;
  children: React.ReactNode;
}) {
  return (
    <Link href={getSpaceUrl(name) + '/-/audit'}>
      <a>{children}</a>
    </Link>
  );
}

export function getResourceUrl(res: Resource): string {
  return '/r/' + res.resource_type + ':' + res.resource_id;
}

export function LinkResource({
  res,
  children,
}: {
  res: Resource;
  children: React.ReactNode;
}) {
  return (
    <Link href={getResourceUrl(res)}>
      <a>{children}</a>
    </Link>
  );
}

export function getTeamUrl(spaceName: string, teamName: string): string {
  return getSpaceUrl(spaceName) + '/-/team/' + teamName;
}

export function LinkTeam({
  spaceName,
  teamName,
  children,
}: {
  spaceName: string;
  teamName: string;
  children: React.ReactNode;
}) {
  return (
    <Link href={getTeamUrl(spaceName, teamName)}>
      <a>{children}</a>
    </Link>
  );
}
