export interface User {
  user_id: number;
  name: string;
  email_address: string | null;
  auth0_sub: string | null;
}

export interface Resource {
  resource_type: string;
  resource_id: string;
}

export interface Space {
  space_id: number;
  name: string;
  fullname: string;
  parent_space_id: number | null;
}

export interface SpaceOwner {
  space_id: number;
  user_id: number;
}

export interface Team {
  team_id: number;
  space_id: number;
  name: string;
}

export type TeamOrOwners = Team | 'owners';

export interface TeamUser {
  team_id: number;
  user_id: number;
}

export interface SpaceResource {
  space_id: number;
  resource_type: string;
  resource_id: string;
}

export interface ResourcePermission {
  id: number;
  space_id: number;
  resource_type: string;
  resource_id: string;
  team_id: number | null;
  user_id: number | null;
  permission: string;
  apply_here: boolean;
  inherit: boolean;
}

export interface K8sResource extends Resource {
  resource_type: 'k8s';
  cpu_quota: string | null;
  memory_quota: string | null;
}

export interface DeviceResource extends Resource {
  resource_type: 'device';
  mac_address: string;
}

export type ConcreteResource = K8sResource | DeviceResource;
