import {Knex} from 'knex';

export async function seed(knex: Knex): Promise<void> {
  // Deletes ALL existing entries
  await knex('device_resources').del();
  await knex('k8s_resources').del();
  await knex('resource_permissions').del();
  await knex('space_resources').del();
  await knex('team_users').del();
  await knex('teams').del();
  await knex('space_owners').del();
  await knex('spaces').del();
  await knex('resources').del();
  await knex('users').del();

  // Insert seed entries
  await knex('users').insert([
    {
      user_id: 1,
      name: 'Rob Pahle',
      email_address: 'rp2585@nyu.edu',
      auth0_sub: 'oauth2|CILogon|http://cilogon.org/serverA/users/326236',
    },
    {
      user_id: 2,
      name: 'Jeremy Rowe',
      email_address: 'jr4121@nyu.edu',
      auth0_sub: 'oauth2|Other|jeremy',
    },
    {
      user_id: 3,
      name: 'Remi Rampin',
      email_address: 'remi.rampin@nyu.edu',
      auth0_sub: 'oauth2|CILogon|http://cilogon.org/serverA/users/9021171',
    },
    {
      user_id: 4,
      name: 'Rheya Vithalani',
      email_address: 'rrv7869@nyu.edu',
      auth0_sub: 'oauth2|CILogon|http://cilogon.org/serverA/users/51521271',
    },
  ]);

  await knex('resources').insert([
    {
      resource_type: '',
      resource_id: 'k8s',
    },
    {
      resource_type: '',
      resource_id: 'space',
    },
    {
      resource_type: '',
      resource_id: 'device',
    },
    {
      resource_type: 'k8s',
      resource_id: 'zeek-elasticsearch',
    },
    {
      resource_type: 'k8s',
      resource_id: 'playground',
    },
  ]);

  await knex('spaces').insert([
    {
      space_id: 0,
      name: 'nyu',
      parent_space_id: null,
    },
    {
      space_id: 1,
      name: 'hsrn',
      parent_space_id: 0,
    },
    {
      space_id: 2,
      name: 'dashboard',
      parent_space_id: 1,
    },
    {
      space_id: 3,
      name: 'bob-class-project',
      parent_space_id: 1,
    },
  ]);

  await knex('space_owners').insert([
    {
      space_id: 1,
      user_id: 1,
    },
    {
      space_id: 1,
      user_id: 2,
    },
    {
      space_id: 2,
      user_id: 3,
    },
    {
      space_id: 3,
      user_id: 4,
    },
  ]);

  await knex('teams').insert([
    {
      team_id: 0,
      space_id: 0,
      name: 'researchers',
    },
    {
      team_id: 1,
      space_id: 0,
      name: 'students',
    },
    {
      team_id: 2,
      space_id: 1,
      name: 'leadership',
    },
    {
      team_id: 3,
      space_id: 1,
      name: 'interns',
    },
  ]);

  await knex('team_users').insert([
    {
      team_id: 0,
      user_id: 1,
    },
    {
      team_id: 0,
      user_id: 2,
    },
    {
      team_id: 0,
      user_id: 3,
    },
    {
      team_id: 1,
      user_id: 4,
    },
    {
      team_id: 2,
      user_id: 1,
    },
    {
      team_id: 2,
      user_id: 2,
    },
    {
      team_id: 2,
      user_id: 3,
    },
  ]);

  await knex('space_resources').insert([
    {
      space_id: 0,
      resource_type: '',
      resource_id: 'space',
    },
    {
      space_id: 0,
      resource_type: '',
      resource_id: 'k8s',
    },
    {
      space_id: 0,
      resource_type: '',
      resource_id: 'device',
    },
    {
      space_id: 1,
      resource_type: '',
      resource_id: 'space',
    },
    {
      space_id: 1,
      resource_type: '',
      resource_id: 'k8s',
    },
    {
      space_id: 1,
      resource_type: '',
      resource_id: 'device',
    },
    {
      space_id: 1,
      resource_type: 'k8s',
      resource_id: 'zeek-elasticsearch',
    },
    {
      space_id: 1,
      resource_type: 'k8s',
      resource_id: 'playground',
    },
    {
      space_id: 2,
      resource_type: '',
      resource_id: 'space',
    },
    {
      space_id: 2,
      resource_type: '',
      resource_id: 'k8s',
    },
    {
      space_id: 2,
      resource_type: 'k8s',
      resource_id: 'playground',
    },
    {
      space_id: 3,
      resource_type: 'k8s',
      resource_id: 'playground',
    },
  ]);

  await knex('resource_permissions').insert([
    {
      id: 1,
      space_id: 0,
      resource_type: '',
      resource_id: 'space',
      team_id: 0,
      user_id: null,
      permission: 'create',
      apply_here: 1,
      inherit: 1,
    },
    {
      id: 2,
      space_id: 0,
      resource_type: '',
      resource_id: 'space',
      team_id: 1,
      user_id: null,
      permission: 'create',
      apply_here: 1,
      inherit: 1,
    },
    {
      id: 3,
      space_id: 0,
      resource_type: '',
      resource_id: 'k8s',
      team_id: 0,
      user_id: null,
      permission: 'createNamespace',
      apply_here: 0,
      inherit: 1,
    },
    {
      id: 4,
      space_id: 0,
      resource_type: '',
      resource_id: 'device',
      team_id: 0,
      user_id: null,
      permission: 'register',
      apply_here: 0,
      inherit: 1,
    },
    {
      id: 5,
      space_id: 0,
      resource_type: '',
      resource_id: 'device',
      team_id: 1,
      user_id: null,
      permission: 'register',
      apply_here: 0,
      inherit: 1,
    },
    {
      id: 101,
      space_id: 1,
      resource_type: '',
      resource_id: 'space',
      team_id: null,
      user_id: null,
      permission: 'create',
      apply_here: 1,
      inherit: 1,
    },
    {
      id: 102,
      space_id: 1,
      resource_type: '',
      resource_id: 'space',
      team_id: 2,
      user_id: null,
      permission: 'create',
      apply_here: 1,
      inherit: 1,
    },
    {
      id: 103,
      space_id: 1,
      resource_type: '',
      resource_id: 'space',
      team_id: 3,
      user_id: null,
      permission: 'create',
      apply_here: 1,
      inherit: 0,
    },
    {
      id: 104,
      space_id: 1,
      resource_type: '',
      resource_id: 'k8s',
      team_id: null,
      user_id: null,
      permission: 'createNamespace',
      apply_here: 1,
      inherit: 1,
    },
    {
      id: 105,
      space_id: 1,
      resource_type: '',
      resource_id: 'k8s',
      team_id: 2,
      user_id: null,
      permission: 'createNamespace',
      apply_here: 1,
      inherit: 1,
    },
    {
      id: 106,
      space_id: 1,
      resource_type: '',
      resource_id: 'device',
      team_id: null,
      user_id: null,
      permission: 'register',
      apply_here: 1,
      inherit: 1,
    },
    {
      id: 107,
      space_id: 1,
      resource_type: '',
      resource_id: 'device',
      team_id: 2,
      user_id: null,
      permission: 'register',
      apply_here: 1,
      inherit: 0,
    },
    {
      id: 108,
      space_id: 1,
      resource_type: '',
      resource_id: 'device',
      team_id: 3,
      user_id: null,
      permission: 'register',
      apply_here: 1,
      inherit: 0,
    },
    {
      id: 109,
      space_id: 1,
      resource_type: 'k8s',
      resource_id: 'zeek-elasticsearch',
      team_id: null,
      user_id: null,
      permission: 'read',
      apply_here: 1,
      inherit: 1,
    },
    {
      id: 110,
      space_id: 1,
      resource_type: 'k8s',
      resource_id: 'zeek-elasticsearch',
      team_id: null,
      user_id: null,
      permission: 'write',
      apply_here: 1,
      inherit: 1,
    },
    {
      id: 111,
      space_id: 1,
      resource_type: 'k8s',
      resource_id: 'zeek-elasticsearch',
      team_id: 2,
      user_id: null,
      permission: 'read',
      apply_here: 1,
      inherit: 0,
    },
    {
      id: 112,
      space_id: 1,
      resource_type: 'k8s',
      resource_id: 'zeek-elasticsearch',
      team_id: 2,
      user_id: null,
      permission: 'write',
      apply_here: 1,
      inherit: 0,
    },
    {
      id: 113,
      space_id: 1,
      resource_type: 'k8s',
      resource_id: 'zeek-elasticsearch',
      team_id: 3,
      user_id: null,
      permission: 'read',
      apply_here: 1,
      inherit: 0,
    },
    {
      id: 114,
      space_id: 1,
      resource_type: 'k8s',
      resource_id: 'playground',
      team_id: null,
      user_id: null,
      permission: 'read',
      apply_here: 1,
      inherit: 1,
    },
    {
      id: 115,
      space_id: 1,
      resource_type: 'k8s',
      resource_id: 'playground',
      team_id: null,
      user_id: null,
      permission: 'write',
      apply_here: 1,
      inherit: 1,
    },
    {
      id: 116,
      space_id: 1,
      resource_type: 'k8s',
      resource_id: 'playground',
      team_id: 2,
      user_id: null,
      permission: 'read',
      apply_here: 1,
      inherit: 1,
    },
    {
      id: 117,
      space_id: 1,
      resource_type: 'k8s',
      resource_id: 'playground',
      team_id: 2,
      user_id: null,
      permission: 'write',
      apply_here: 1,
      inherit: 1,
    },
    {
      id: 118,
      space_id: 1,
      resource_type: 'k8s',
      resource_id: 'playground',
      team_id: 3,
      user_id: null,
      permission: 'read',
      apply_here: 1,
      inherit: 1,
    },
    {
      id: 201,
      space_id: 2,
      resource_type: '',
      resource_id: 'space',
      team_id: null,
      user_id: null,
      permission: 'create',
      apply_here: 1,
      inherit: 1,
    },
    {
      id: 202,
      space_id: 2,
      resource_type: '',
      resource_id: 'k8s',
      team_id: null,
      user_id: null,
      permission: 'createNamespace',
      apply_here: 1,
      inherit: 1,
    },
    {
      id: 203,
      space_id: 2,
      resource_type: 'k8s',
      resource_id: 'playground',
      team_id: null,
      user_id: null,
      permission: 'read',
      apply_here: 1,
      inherit: 1,
    },
    {
      id: 204,
      space_id: 2,
      resource_type: 'k8s',
      resource_id: 'playground',
      team_id: null,
      user_id: null,
      permission: 'write',
      apply_here: 1,
      inherit: 1,
    },
    {
      id: 301,
      space_id: 3,
      resource_type: 'k8s',
      resource_id: 'playground',
      team_id: null,
      user_id: null,
      permission: 'read',
      apply_here: 1,
      inherit: 1,
    },
  ]);

  await knex('k8s_resources').insert([
    {
      resource_type: 'k8s',
      resource_id: 'zeek-elasticsearch',
      cpu_quota: '10',
    },
    {
      resource_type: 'k8s',
      resource_id: 'playground',
      cpu_quota: '1500m',
      memory_quota: '60Gi',
    },
  ]);

  // Reset sequences
  if (knex.client.dialect === 'postgresql') {
    await knex.select(
      knex.raw(
        "setval('resource_permissions_id_seq', (select max(id) from resource_permissions))"
      ),
      knex.raw(
        "setval('spaces_space_id_seq', (select max(space_id) from spaces))"
      ),
      knex.raw("setval('teams_team_id_seq', (select max(team_id) from teams))"),
      knex.raw("setval('users_user_id_seq', (select max(user_id) from users))")
    );
  }
}
