import type {Knex} from 'knex';

const config: {[key: string]: Knex.Config} = {
  development: {
    client: 'sqlite3',
    connection: {
      filename: './test.sqlite3',
    },
    seeds: {
      directory: './database/seeds',
    },
    migrations: {
      directory: './database/migrations',
    },
    debug: true,
    useNullAsDefault: true,
  },
  production: {
    client: 'postgres',
    connection: {
      host: process.env.POSTGRES_HOST,
      port: 5432,
      user: process.env.POSTGRES_USER,
      password: process.env.POSTGRES_PASSWORD,
      database: process.env.POSTGRES_DATABASE,
    },
    seeds: {
      directory: './database/seeds',
    },
    migrations: {
      directory: './database/migrations',
    },
    pool: {
      min: 0,
      max: 8,
      idleTimeoutMillis: 30000,
    },
  },
};

export default config;
