import knex from './knex';
import {UserProfile} from '@auth0/nextjs-auth0';
import {User} from '../database/models';

// Get a database User from a auth0 UserProfile
//
// This will create a user first if it doesn't exist.
export async function getOrCreateUser(user: UserProfile): Promise<User> {
  function getUser() {
    return knex<User>('users').where('auth0_sub', user.sub).first();
  }

  // First try to get an existing user
  let row = await getUser();
  if (row) {
    return row;
  }

  // Insert new user
  await knex<User>('users').insert(
    {
      email_address: user.email!,
      name: user.name!,
      auth0_sub: user.sub!,
    },
    ['user_id']
  );

  // Get it again
  row = await getUser();
  return row!;
}
