import {GetServerSidePropsContext, GetServerSidePropsResult} from 'next';
import {getSession} from '@auth0/nextjs-auth0';
import {Space, TeamOrOwners, User} from '../database/models';
import {getOrCreateUser} from '../lib/get_user';
import {reportMetrics} from '../lib/metrics';
import {getUserOwnedSpaces, getUserSpaces} from '../lib/queries';
import {Welcome} from '../components/welcome';
import {Dashboard} from '../components/dashboard';
import {Layout} from '../components/layout';

interface HomeProps {
  user: User | null;
  ownedSpaces: Space[];
  spaces: Array<{space: Space; team: TeamOrOwners}>;
}

export default function HomePage({user, ownedSpaces, spaces}: HomeProps) {
  if (!user) {
    return (
      <Layout user={null}>
        <Welcome />
      </Layout>
    );
  } else {
    return (
      <Layout user={user}>
        <Dashboard user={user} ownedSpaces={ownedSpaces} spaces={spaces} />
      </Layout>
    );
  }
}

export const getServerSideProps = reportMetrics(
  'index',
  async (
    ctx: GetServerSidePropsContext
  ): Promise<GetServerSidePropsResult<HomeProps>> => {
    const session = getSession(ctx.req, ctx.res);
    let ownedSpaces: Space[] = [];
    let spaces: Array<{space: Space; team: TeamOrOwners}> = [];
    let user = null;
    if (session) {
      user = await getOrCreateUser(session.user);
      ownedSpaces = await getUserOwnedSpaces(user.user_id);
      spaces = await getUserSpaces(user.user_id);
    }
    return {
      props: {
        user,
        ownedSpaces,
        spaces,
      },
    };
  }
);
